# More Files!

The `File` class makes the default assumption all files have cr-delimited unicode content that is UTF-8 encoded. This is great for JSON files. It also provides better operators over some common file manipulations.







## Recent changes

**Version 6.x**

Get a little closer to Python's pathlib module standards

* `stem` - to refer file name without extension
* `os_path` - to get the os-specific absolute path for use in other Python modules
* `rel_path` - the given path 
* `abs_path` - added underscore for consistency 



